@@ -31,6 +31,7 @@ from sys import version_info
 from ajsonapi.application import Application
 from ajsonapi.attribute import Attribute
 from ajsonapi.errors import AuthorizationError
+from ajsonapi.id import Id
 from ajsonapi.json_api import JSON_API
 from ajsonapi.relationships import (
     ManyToManyRelationship,
@@ -39,6 +40,7 @@ from ajsonapi.relationships import (
     OneToOneLocalRelationship,
     OneToOneRemoteRelationship,
 )
+from ajsonapi.responses import errors_response
 from ajsonapi.types import Boolean  # deprecating
 from ajsonapi.types import DateTimeTimeZone  # deprecating
 from ajsonapi.types import (
@@ -52,10 +54,11 @@ from ajsonapi.types import (
     Int64,
     Json,
     String,
+    Uuid,
 )
 
 assert version_info >= (3, 7), 'Need Python 3.7+ for module ajsonapi'
 del version_info
 
 __docformat__ = 'restructuredtext'
-__version__ = '0.6.8'
+__version__ = '0.7.0'
