@@ -38,7 +38,7 @@ from ajsonapi.errors import (
     DocumentNotJsonError,
 )
 from ajsonapi.exceptions import ErrorsException, TypeNameError
-from ajsonapi.id import Id
+from ajsonapi.id_value import IdValue
 
 
 class Document:
@@ -228,7 +228,7 @@ class ResourceIdentifierObjectDocument(Document):
         try:
             id_name = self.data['id']
             try:
-                self.id = Id(id_name)
+                self.id = IdValue(id_name)
             except ValueError:
                 errors.append(
                     DocumentDataMalformedIdError(
@@ -295,7 +295,7 @@ class ResourceIdentifierObjectsDocument(Document):
             obj_type_names = {obj['type'] for obj in self.data}
             if not obj_type_names <= {expected_type_name}:
                 raise TypeNameError()
-            self.ids = [Id(obj['id']) for obj in self.data]
+            self.ids = [IdValue(obj['id']) for obj in self.data]
         except (KeyError, ValueError, TypeNameError):
             errors = []
             for index, roi in enumerate(self.data):
