@@ -20,16 +20,32 @@
 #
 """Module id provides class Id."""
 
-from ajsonapi.conversions import id_name_to_number
+from ajsonapi.types import Uuid
 
 
 class Id:
-    """Class Uuid keeps track of the original name of an id used in the
-    request (URI or request document).
-    """
+    """Class representing the "id" column in JSON_API classes."""
 
-    # pylint: disable=too-few-public-methods
+    def __init__(self, type_):
+        self.type_ = type_
+        self.table_name = None  # Overriden in JSON_API.__init_subclass__
 
-    def __init__(self, name):
-        self.name = name
-        self.number = id_name_to_number(name)
+    def sql(self):
+        """Returns the column definition for the "id" field."""
+        # pylint: disable=no-self-use
+
+        if self.type_ == Uuid:
+            return "id UUID DEFAULT uuid_generate_v4()"
+        # self.type_ == Int64
+        return (
+            f"id UUID DEFAULT CAST"
+            f"(LPAD(TO_HEX(nextval('seq_{self.table_name}')), 32, '0') AS UUID)"
+        )
+
+    def sql_constraints(self):
+        """Returns the constraints for the "id" field."""
+        # pylint: disable=no-self-use
+        return 'PRIMARY KEY (id)'
+
+    def __str__(self):
+        return 'id'
