@@ -22,9 +22,10 @@
 
 from itertools import chain
 
-from ajsonapi.id_column import IdColumn
+from ajsonapi.id import Id
 from ajsonapi.logging import log
 from ajsonapi.table import Table
+from ajsonapi.types import Int64, Uuid
 
 
 class JSON_API(Table):
@@ -37,7 +38,9 @@ class JSON_API(Table):
     @classmethod
     def __init_subclass__(cls):
         super().__init_subclass__()
-        cls.id = IdColumn(cls.name)
+        if not hasattr(cls, 'id'):
+            cls.id = Id(Int64)
+        cls.id.table_name = cls.name
         cls.columns.insert(0, cls.id)
         cls.constraints.insert(0, cls.id)
 
@@ -53,8 +56,11 @@ class JSON_API(Table):
         table_fields = ',\n    '.join(
             chain((col.sql() for col in cls.columns),
                   (col.sql_constraints() for col in cls.constraints)))
-        stmts = (f'CREATE SEQUENCE IF NOT EXISTS seq_{cls.name}; '
-                 f'CREATE TABLE IF NOT EXISTS {cls.name} ({table_fields});')
+        if cls.id.type_ == Uuid:
+            stmts = f'CREATE TABLE IF NOT EXISTS {cls.name} ({table_fields});'
+        else:  # cls.id.type_ == Int64
+            stmts = (f'CREATE SEQUENCE IF NOT EXISTS seq_{cls.name}; '
+                     f'CREATE TABLE IF NOT EXISTS {cls.name} ({table_fields});')
         async with cls.pool.acquire() as connection:
             log.debug(stmts)
             await connection.execute(stmts)
