@@ -35,7 +35,7 @@ from ajsonapi.errors import (
 )
 from ajsonapi.exceptions import NonexistentRelationshipIdError
 from ajsonapi.field import Field
-from ajsonapi.id import Id
+from ajsonapi.id_value import IdValue
 from ajsonapi.logging import log
 from ajsonapi.uri.related import (
     ManyToManyRelatedResource,
@@ -176,7 +176,7 @@ class ToOneRelationship(Relationship):
         try:
             data_rio_id_name = data_rio['id']
             try:
-                return Id(data_rio_id_name)
+                return IdValue(data_rio_id_name)
             except ValueError:
                 errors.append(
                     DocumentDataMalformedRelationshipIdError(
@@ -242,7 +242,7 @@ class ToManyRelationship(Relationship):
             try:
                 data_rio_id_name = data_rio['id']
                 try:
-                    data_rio_id = Id(data_rio_id_name)
+                    data_rio_id = IdValue(data_rio_id_name)
                     data_rio_ids.append(data_rio_id)
                 except ValueError:
                     errors.append(
