@@ -34,7 +34,7 @@ from ajsonapi.errors import (
 )
 from ajsonapi.events import DeleteEvent, UpdateEvent
 from ajsonapi.exceptions import ErrorsException, NonexistentRelationshipIdError
-from ajsonapi.id import Id
+from ajsonapi.id_value import IdValue
 from ajsonapi.logging import log
 from ajsonapi.responses import document_response, no_data_response
 from ajsonapi.uri.collection import (
@@ -444,7 +444,7 @@ def parse(request):
         raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')])
 
     try:
-        id_ = Id(id_name)
+        id_ = IdValue(id_name)
     except ValueError:
         raise ErrorsException(
             [ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')])
