@@ -31,7 +31,7 @@ from ajsonapi.errors import (
     ResourceNotFoundMalformedIdError,
 )
 from ajsonapi.exceptions import ErrorsException
-from ajsonapi.id import Id
+from ajsonapi.id_value import IdValue
 from ajsonapi.logging import log
 from ajsonapi.responses import document_response
 from ajsonapi.uri.collection import Collection
@@ -633,7 +633,7 @@ def make_related_resource(collection_name, id_name, related_resource_name):
         raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')])
 
     try:
-        id_ = Id(id_name)
+        id_ = IdValue(id_name)
     except ValueError:
         raise ErrorsException(
             [ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')])
